aboutsummaryrefslogtreecommitdiff
path: root/src/gr/AHFinderDirect.hh
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-21 17:01:39 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-21 17:01:39 +0000
commite2933f68a4e11f58e8115b08ded649bd867cf135 (patch)
tree87531165859adc37a9c2d7ad161390a29317f50d /src/gr/AHFinderDirect.hh
parent854185f3bab9964edf3ef8f300b7bcd8b7be207d (diff)
fix assorted syntax errors --> now compiles cleanly!
git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@550 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/gr/AHFinderDirect.hh')
-rw-r--r--src/gr/AHFinderDirect.hh9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/gr/AHFinderDirect.hh b/src/gr/AHFinderDirect.hh
index 36a3909..59dacb8 100644
--- a/src/gr/AHFinderDirect.hh
+++ b/src/gr/AHFinderDirect.hh
@@ -9,9 +9,10 @@ enum { N_GRID_DIMS = 3, N_HORIZON_DIMS = 2 };
//
// This structure holds various information about the interpolator
// used to interpolate Cactus 3-D gridfns to the apparent horizon position.
//
-struct interpolator_info
+struct geometry_interpolator_info
{
int operator_handle; // Cactus handle to interpolation op
int param_table_handle; // Cactus handle to parameter table
@@ -65,5 +66,5 @@ extern "C"
// horizon_function.cc
void horizon_function(patch_system& ps,
- struct cactus_grid_info& cgi,
- struct interpolator_info& ii);
+ const struct cactus_grid_info& cgi,
+ const struct geometry_interpolator_info& gii);
@@ -9,9 +9,10 @@ enum { N_GRID_DIMS = 3, N_HORIZON_DIMS = 2 };
//
// This structure holds various information about the interpolator
-// used to interpolate Cactus 3-D gridfns to the apparent horizon position.
+// used to interpolate the "geometry" Cactus 3-D gridfns ($g_{ij}$ and
+// $K_{ij}$) to the apparent horizon position.
//